% m-file for producing the results of the following paper:
% Nordhoff, S., De Winter, J. C. F., Madigan, R., Merat, N., Van Arem, B., & Happee, R. (2018). User acceptance of automated shuttles in Berlin-Schneberg: A questionnaire study. Transportation Research Part F.

clear all;close all force;clc %#ok<CLALL>
one96=norminv(0.975); % 1.96

[X,~,raw]=xlsread('questionnaire data per respondent.xlsx','A3:EI489');
StartTime=datenum(raw(:,71));
[StartTime,b]=sort(StartTime);
X=X(b,:);raw=raw(b,:); % sort all respondents on start time
EndTime=datenum(raw(:,69));
temp=find(diff(StartTime)== 0 & diff(EndTime)==0);
X(temp,:)=[];raw(temp,:)=[]; % remove duplicates
X(X==8888888)=NaN;X(X==9999999)=NaN;
raw(X(:,2)==2,:)=[]; % remove people who complete it for the second time
X(X(:,2)==2,:)=[]; % remove people who complete it for the second time
StartTime=datenum(raw(:,71));
%X(isnan(X(:,42)) & isnan(X(:,42)),:)=[];
%X(isnan(X(:,89)) & isnan(X(:,90)),:)=[];
% 4 = Gender (1 = male, 2 = female)  Q2
% 5 = Age Q3
% 6 = working on EUREF campus (1 = yes, 2 = no) Q4
% 7 = working domain Q5
% 8-15 = mode of transport (8 = Electo scooter, 9 = Electric vehicle, 10 = Bicycle, 11 = Conventional vehicle with combustion engine, 12 = Truck, 13 = On foot, 14 = Other
% 16 = have used shuttle before (1 = yes, 2 = no) Q7
% 17 = how many times before  Q8
% 18-20 = Please evaluate the service in total (1 = very good, 6 = very bad) Q9-Q11
% 21-37 = Please evaluate the vehicle in total (1 = very good, 6 = very bad) Q12-Q28
% 38-42 = vision (1 = very good, 6 = very bad) Q29-Q33
% 44 = 91 = NutzungA = I would use an electric driverless vehicle from the train station or some other public transport stop to my final destination or vice versa.
% 47 = Nutzung oft = Please indicate how often you intend to use a driverless vehicle when it is available on the market (1 = daily or almost daily, 5 = never or almost never, 6 = I don't know)
% 48-56 = SemDiff = Van der Laan (1-5) Q63
% 57 = Driverless vehicles can operate without human supervision. Would you still prefer having some level of supervision? (1, 2, or 3)
% 77-90 = Bew1A-N (Taking a ride in the driverless shuttle was fun and enjoyable, and other questions) (1 = disagree strongly, 6 = agree strongly, 7 = I do not know)
% 91-97, 117 = Akzeptanz_Nutzun (I would use an electric driverless vehicle from the train station... (1 = disagree strongly, 6 = agree strongly, 7 = I do not know)
% 103,104,58-63 = Bew2 (I feel comfortable in a vehicle without steering wheel, gas or brake pedal; and other trust questions (1 = disagree strongly, 6 = agree strongly, 7 = I do not know)
% 105-106 = I would use driverless shuttles as mobility offer in rural areas, I would use driverless shuttles as mobility offer in the city (1 = disagree strongly, 7 = agree strongly, 7 = I do not know)
% 118 = Wieviel wrden Sie fr die Nutzung eines fahrelosen Shuttles fr die Nutzung von 10 Minuten bezahlen? (1 = EUR 2.50-3.00, 7 = Gar nichts, 8 = I do not know)
%%
X(:,6)=3-X(:,6); % EUREF campus 1 = no, 2 = yes

disp('Total number of participants, number of males, number of females, number unknown gender')
disp([size(X,1) sum(X(:,4)==1) sum(X(:,4)==2) sum(isnan(X(:,4)))])
disp('Mean age (SD)')
disp(round([nanmean(X(:,5)) nanstd(X(:,5))],1))

% 18-42
disp('Q9-Q33, mean, SD, and number of responses from very bad to very good')
X(:,18:42)=7-X(:,18:42);
h=histc(X(:,18:42),1:6)';
disp([nanmean(X(:,18:42))' nanstd(X(:,18:42))' h(:,1:6)])

disp('Q66-1 to Q66-9: Van der Laan acceptance scale')
X(:,47+[1 2 4 5 7 9])=6-X(:,47+[1 2 4 5 7 9]); % sign reversal for 6 Van der Laan items
h=histc(X(:,48:56),1:5)';
M=nanmean(X(:,48:56))';
SD=nanstd(X(:,48:56))';
disp([M SD h])

V=[77:90 91:97 117 103 104 58:63 105 106];
disp('Q34-Q64, from disagree strongly (1) to agree strongly (6) (7 = I do not know)')
h=histc(X(:,V),1:7)';
disp(h)
for i=1:length(V)
    X(X(:,V(i))==7,V(i))=NaN;
end
disp('From disagree strongly to agree strongly (I do not know removed)')
h=histc(X(:,V),1:6)';
disp([nanmean(X(:,V))' nanstd(X(:,V))' h])

disp('Q65. Please indicate how often you intend to use a driverless vehicle when it is available on the market, 1 = daily or almost daily, 5 = never of almost never, 6 = I don''t know.')
h=histc(X(:,47),1:6)';
X(X(:,47)==6,47)=NaN;
disp([nanmean(X(:,47))' nanstd(X(:,47))' h])

disp('Q68. With the following and last question, we would like to know from you how much you would be willing to pay for the use of the driverless shuttle for a 10-minute use')
h=histc(X(:,118),1:8)';
X(X(:,118)==8,118)=NaN;
X(:,118)=8-X(:,118);
disp([nanmean(X(:,118))' nanstd(X(:,118))' h])

disp('Q67. Driverless vehicles can operate without human supervision. Would you still prefer having some level of supervision?')
h=histc(X(:,57),1:3)';
disp(h)

X2=X(:,[18:42 48:56 77:90 91:97 117 103 58:63 105:106 47 118]);
%% Histogram of Q24 and Q59
figure('name','Figure 5 left. Q24. brightness','numbertitle','off');hold on
bar(histc(X2(:,16),1:6),'facecolor',[.8 .8 .8])
labels={'1. Very bad','2','3','4','5','6. Very good'};
set(gca,'ylim',[0 200])
set(gca,'xtick',1:6,'LooseInset',[0.01 0.01 0.01 0.01],'xticklabel',labels);
xlabel('Rating')
ylabel('Number of respondents')
title('Q24. Brightness')
fig=gcf;set(findall(fig,'-property','FontName'),'FontName','Arial','Fontsize',24)
box on

figure('name','Figure 5 right. Q59. I would like to manually steer the driverless shuttle when I want this','numbertitle','off');hold on
bar(histc(X2(:,60),1:6),'facecolor',[.8 .8 .8])
labels={'1. Disagree strongly','2','3','4','5','6. Agree strongly'};
set(gca,'ylim',[0 75])
set(gca,'xtick',1:6,'LooseInset',[0.01 0.01 0.01 0.01],'xticklabel',labels);
xlabel('Rating')
ylabel('Number of respondents')
title('Q59. I would like to manually steer the driverless shuttle when I want this')
fig=gcf;set(findall(fig,'-property','FontName'),'FontName','Arial','Fontsize',24)
box on
%%
figure('name','Figure 3. Shuttle and service characteristics','numbertitle','off');hold on
temp=nanmean(X2(:,1:25));
[~,b]=sort(temp);
barh(temp(b),'facecolor',[.8 .8 .8])
for i=1:25
    temp1=X2(:,b(i));
    plot([nanmean(temp1) + one96*(nanstd(temp1)/sqrt(sum(~isnan(temp1)))), nanmean(temp1) - one96*(nanstd(temp1)/sqrt(sum(~isnan(temp1))))], [i i],'k');
    plot([nanmean(temp1) + one96*(nanstd(temp1)/sqrt(sum(~isnan(temp1)))) nanmean(temp1) + one96*(nanstd(temp1)/sqrt(sum(~isnan(temp1))))], [i+2/7 i-2/7],'k');
    plot([nanmean(temp1) - one96*(nanstd(temp1)/sqrt(sum(~isnan(temp1)))) nanmean(temp1) - one96*(nanstd(temp1)/sqrt(sum(~isnan(temp1))))], [i+2/7 i-2/7],'k');
end
labels={'Q9. Shuttle attractiveness'
    'Q10. Shuttle reliability'
    'Q11. Shuttle usability/comfort'
    'Q12. Vehicle attractiveness'
    'Q13. Size of bus'
    'Q14. Exterior quality'
    'Q15. Exterior design'
    'Q16. Vehicle speed'
    'Q17. Entry/exit comfort'
    'Q18. Spaciousness'
    'Q19. Number of seats'
    'Q20. Seating comfort'
    'Q21. Standing room'
    'Q22. Grips'
    'Q23. Space for luggage'
    'Q24. Brightness'
    'Q25. Interior quality'
    'Q26. Interior design'
    'Q27. Atmosphere'
    'Q28. Safety'
    'Q29. Like trip'
    'Q30. Like in public transport'
    'Q31. Envision service in city'
    'Q32. Envision service in rural'
    'Q33. Fit to railway facilities'};
plot([3.5 3.5],[-100 100],'k:','Linewidth',2)
set(gca,'ytick',1:25,'xlim',[1 6],'ylim',[0.2 25.8],'tickdir','out','ydir','reverse','LooseInset',[0.01 0.01 0.01 0.01],'Yticklabel',labels(b));
xlabel('Rating (1 = Very bad, 6 = Very good)')
set(gca,'xlim',[3 6])
fig=gcf;set(findall(fig,'-property','FontName'),'FontName','Arial','Fontsize',18)
box on
%%
figure('name','Figure 6. Van der Laan acceptance questionnaire','numbertitle','off');hold on
grid on
plot(nanmean(X2(:,26:34)),'k-s','Linewidth',2,'Markersize',16)
for i=1:9
    temp1=X2(:,i+25);
    plot([i i],[nanmean(temp1) + one96*(nanstd(temp1)/sqrt(sum(~isnan(temp1)))), nanmean(temp1) - one96*(nanstd(temp1)/sqrt(sum(~isnan(temp1))))],'color',[.5 .5 .5]);
    plot([i+1/7 i-1/7],[nanmean(temp1) + one96*(nanstd(temp1)/sqrt(sum(~isnan(temp1)))) nanmean(temp1) + one96*(nanstd(temp1)/sqrt(sum(~isnan(temp1))))],'color',[.5 .5 .5]);
    plot([i+1/7 i-1/7],[nanmean(temp1) - one96*(nanstd(temp1)/sqrt(sum(~isnan(temp1)))) nanmean(temp1) - one96*(nanstd(temp1)/sqrt(sum(~isnan(temp1))))],'color',[.5 .5 .5]);
end

plot([-10 10],[3 3],'k:','Linewidth',2)
fig=gcf;set(findall(fig,'-property','FontSize'),'FontSize',15)
set(gca,'xlim',[.7 9.3])
set(gca,'ylim',[1 5]);
h1=gca;
set(h1,'XTickLabel',{'1. Useless' '2. Unpleasant' '3. Bad' '4. Annoying' '5. Superfluous' '6. Irritating' '7. Worthless' '8. Undesirable' '9. Sleep-inducing' })
set(h1,'Fontsize',13)
h2 = axes ('Position', get (h1, 'Position'));
set (h2, 'YAxisLocation', 'right', 'XAxisLocation', 'top', ...
    'Color', 'None')
set(h2,'XTickLabel',{'1. Useful' '2. Pleasant' '3. Good' '4. Nice' '5. Effective' '6. Likeable' '7. Assisting' '8. Desirable' '9. Raises alertness'})
set(h2,'xlim',[.7 9.3])
set(h2,'ylim',[1 5])
set(h2,'Fontsize',13)
%%
figure('name','Figure 4. Attitudes towards the shuttle','numbertitle','off');hold on
temp=nanmean(X2(:,35:65));
temp(:,[4 14 28])=7-temp(:,[4 14 28]);
[~,b]=sort(temp);
barh(temp(b),'facecolor',[.8 .8 .8])
for i=1:31
    if ismember(b(i),[4 14 28])
        barh(i,7-nanmean(X2(:,b(i)+34)),'facecolor',[.4 .4 .4])
        temp1=X2(:,b(i)+34);
        temp1=7-temp1;
        plot([nanmean(temp1) + one96*(nanstd(temp1)/sqrt(sum(~isnan(temp1)))), nanmean(temp1) - one96*(nanstd(temp1)/sqrt(sum(~isnan(temp1))))], [i i],'k');
        plot([nanmean(temp1) + one96*(nanstd(temp1)/sqrt(sum(~isnan(temp1)))) nanmean(temp1) + one96*(nanstd(temp1)/sqrt(sum(~isnan(temp1))))], [i+2/7 i-2/7],'k');
        plot([nanmean(temp1) - one96*(nanstd(temp1)/sqrt(sum(~isnan(temp1)))) nanmean(temp1) - one96*(nanstd(temp1)/sqrt(sum(~isnan(temp1))))], [i+2/7 i-2/7],'k');
    else
        temp1=X2(:,b(i)+34);
        plot([nanmean(temp1) + one96*(nanstd(temp1)/sqrt(sum(~isnan(temp1)))), nanmean(temp1) - one96*(nanstd(temp1)/sqrt(sum(~isnan(temp1))))], [i i],'k');
        plot([nanmean(temp1) + one96*(nanstd(temp1)/sqrt(sum(~isnan(temp1)))) nanmean(temp1) + one96*(nanstd(temp1)/sqrt(sum(~isnan(temp1))))], [i+2/7 i-2/7],'k');
        plot([nanmean(temp1) - one96*(nanstd(temp1)/sqrt(sum(~isnan(temp1)))) nanmean(temp1) - one96*(nanstd(temp1)/sqrt(sum(~isnan(temp1))))], [i+2/7 i-2/7],'k');
    end
end
labels={'Q34. Was fun'
    'Q35. Like sharing with passengers'
    'Q36. Is useful'
    'Q37. Trip is boring'
    'Q38. Would use commuting because easier'
    'Q39. Shuttle will be important'
    'Q40. Is easier than existing travel'
    'Q41. Is similar to public transport'
    'Q42. Is easy to understand'
    'Q43. Like low speed'
    'Q44. Is more efficient than existing travel'
    'Q45. Would not take long to learn'
    'Q46. Felt safe'
    'Q47. Dislike sharing with passengers'
    'Q48. Would use from train station'
    'Q49. Would share with 6-8 passengers'
    'Q50. Use when available on market'
    'Q51. Use for daily trips'
    'Q52. Replace current travel with shuttle'
    'Q53. Choose shuttle because of environment'
    'Q54. Like 100% electric shuttle'
    'Q55. Choose eco shuttle if more expensive'
    'Q56. Feel comfortable without steer&pedals'
    'Q57. People would like if it I use shuttle'
    'Q58. Prefer no steward on board'
    'Q59. Would like to manually steer shuttle'
    'Q60. Would like stop botton'
    'Q61. Would like others use shuttle before me'
    'Q62. Safe and reliable in severe weather'
    'Q63. Would use shuttles in rural area'
    'Q64. Would use shuttles in city'};
plot([3.5 3.5],[-100 100],'k:','Linewidth',2)
set(gca,'ytick',1:31,'xlim',[1 6],'ylim',[0.2 31.8],'tickdir','out','ydir','reverse','LooseInset',[0.01 0.01 0.01 0.01],'Yticklabel',labels(b));
xlabel('Rating (1 = Disagree strongly, 6 = Agree strongly)')
set(gca,'xlim',[1 6])
fig=gcf;set(findall(fig,'-property','FontName'),'FontName','Arial','Fontsize',17)
box on
%%

PM=nanmean(isnan(X2')); % proportion missing values
PM=unique(find(PM'>=.2));

X(PM,:)=[];
disp('Total number of participants, number of males, number of females, number unknown gender (reduced sample used in PCA)')
disp([size(X,1) sum(X(:,4)==1) sum(X(:,4)==2) sum(isnan(X(:,4)))])
disp('Total number of Euref employees (reduced sample used in PCA)')
disp([size(X,1) sum(X(:,6)==1) sum(X(:,6)==2) sum(isnan(X(:,6)))])
disp('Mean age (SD) (reduced sample used in PCA)')
disp(round([nanmean(X(:,5)) nanstd(X(:,5))],1))
disp('Type of transport on campus (8. Electro scooter, 9. Electric vehicle, 10. Bicyle, 11. Conventional vehicle with combustion engine, 12. Truck, 13. On foot, 14. Other (reduced sample used in PCA')
disp(sum(X(:,8:14)))
X2(PM,:)=[];
X2=knnimpute(X2')';
X3=zscore(X2);r=corr(X3);lding=pcaj(r,3);
lding(:,1)=-lding(:,1);
lding=rotatefactors(lding,'method','promax','power',4,'maxit',25);

eigr=sort(eig(r),'descend');
varexplained=100*(eigr./sum(eigr));
figure('name','Figure 7. Scree plot','numbertitle','off');hold on
plot(eigr,'k-o','Linewidth',3)
ylabel('Eigenvalue')
xlabel('Component number')
fig=gcf;set(findall(fig,'-property','FontName'),'FontName','Arial','Fontsize',24)
set(gca,'LooseInset', [0.01 0.01 0.01 0.01],'xtick',[1 5:5:100]);
set(gca,'xlim',[.5  length(r)+.5])
for i=1:3
    text(i+0.5,eigr(i),[sprintf('%0.1f',varexplained(i)) '%'],'color','b','fontsize',13);
end

iX = inv(r);
S2 = diag(diag((iX.^-1)));
AIS = S2*iX*S2; %#ok<MINV>
Dai = diag(diag(sqrt(AIS)));
AIR = inv(Dai)*AIS*inv(Dai); %#ok<MINV>
AA = sum(sum((AIR - diag(diag(AIR))).^2));
BB = sum(sum((r - eye(size(r))).^2));
kmo = BB/(AA+BB);
disp(['The Kaiser-Meyer-Olkin (KMO) measure of sampling adequacy was ' num2str(kmo)])
disp(['Cronbach''s alpha PCA 1, for the variables that load more strongly than 0.4 = ' num2str(cronbach(X2(:,lding(:,1)>.4)))])
disp(['Cronbach''s alpha PCA 2, for the variables that load more strongly than 0.4 = ' num2str(cronbach(X2(:,lding(:,2)>.4)))])
disp(['Cronbach''s alpha PCA 3, for the variables that load more strongly than 0.4 = ' num2str(cronbach(X2(:,lding(:,3)>.4)))])

sv=X3/lding';
[c,p]=corr([X(:,4:6) sv],'rows','pairwise');
disp('Correlation matrix')
disp(c)

disp('Q6. PCA sample: Type of transport on campus, multiple responses possible (8. Electro scooter, 9. Electric vehicle, 10. Bicyle, 11. Conventional vehicle with combustion engine, 12. Truck, 13. On foot, 14. Other')
disp(sum(X(:,8:14)))

disp('Mean age and PCA scores per mode of transport')
V=[8:11 13 14];
temp=NaN(6,5);
for i=1:length(V);
    temp(i,:)=[sum(X(:,V(i))==1 & X(:,6)==2) round(nanmean(X(X(:,V(i))==1 & X(:,6)==2,5),1),1) round(nanmean(sv(X(:,V(i))==1 & X(:,6)==2,:),1),2)];
    [~,b,~]=ttest(sv(X(:,V(i))==1 & X(:,6)==1,:));
end
disp('Working on the EUREF campus')
disp(temp)
for i=1:length(V);
    temp(i,:)=[sum(X(:,V(i))==1 & X(:,6)==1) round(nanmean(X(X(:,V(i))==1 & X(:,6)==1,5),1),1) round(nanmean(sv(X(:,V(i))==1 & X(:,6)==1,:),1),2)];
end
disp('Not working on the EUREF campus')
disp(temp)
